@@ -562,22 +562,22 @@ class ExecutionServer(BaseServer):
             # Call the function.
             LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
             # Schedule the next request.
-            self._callExposedFunction(
-                exposed_function["function"],
-                exposed_function["interval"], 
-                kwargs, 
-                function_name, 
-                uuid=uuid,
-                reservation_fast_cache=job["reservation_cache"])
-                
-            #reactor.callInThread(
-            #    self._callExposedFunction, 
+            #self._callExposedFunction(
             #    exposed_function["function"],
             #    exposed_function["interval"], 
             #    kwargs, 
             #    function_name, 
             #    uuid=uuid,
             #    reservation_fast_cache=job["reservation_cache"])
+                
+            reactor.callInThread(
+                self._callExposedFunction, 
+                exposed_function["function"],
+                exposed_function["interval"], 
+                kwargs, 
+                function_name, 
+                uuid=uuid,
+                reservation_fast_cache=job["reservation_cache"])
 
     def _callExposedFunction(
         self, 
